@@ -11,18 +11,43 @@ class NMainFrame:
         self.surface = surface
         self.w, self.h = self.surface.get_size()
         self.processes = {
-            pygame.QUIT: 'on_quit',
-            pygame.WINDOWRESIZED: 'on_resize',
+            0: 'on_unknown_event',
+            pygame.AUDIODEVICEADDED: 'on_audio_device_added',
+            pygame.AUDIODEVICEREMOVED: 'on_audio_device_removed',
+            pygame.ACTIVEEVENT: 'on_active',
             pygame.KEYDOWN: 'on_global_key_down',
             pygame.KEYUP: 'on_global_key_up',
             pygame.MOUSEBUTTONDOWN: 'on_global_mouse_down',
             pygame.MOUSEBUTTONUP: 'on_global_mouse_up',
             pygame.MOUSEMOTION: 'on_global_mouse_move',
-            pygame.MOUSEWHEEL: 'on_global_mouse_wheel'
+            pygame.MOUSEWHEEL: 'on_global_mouse_wheel',
+            pygame.QUIT: 'on_quit',
+            pygame.TEXTEDITING: 'on_text_editing',
+            pygame.TEXTINPUT: 'on_text_input',
+            pygame.VIDEOEXPOSE: 'on_video_expose',
+            pygame.VIDEORESIZE: 'on_video_resize',
+            pygame.WINDOWCLOSE: 'on_window_close',
+            pygame.WINDOWENTER: 'on_global_mouse_enter',
+            pygame.WINDOWEXPOSED: 'on_window_exposed',
+            pygame.WINDOWFOCUSGAINED: 'on_window_focus_gained',
+            pygame.WINDOWFOCUSLOST: 'on_window_focus_lost',
+            pygame.WINDOWLEAVE: 'on_global_mouse_leave',
+            pygame.WINDOWMAXIMIZED: 'on_window_maximized',
+            pygame.WINDOWMINIMIZED: 'on_window_minimized',
+            pygame.WINDOWMOVED: 'on_window_moved',
+            pygame.WINDOWRESIZED: 'on_resize',
+            pygame.WINDOWRESTORED: 'on_window_restored',
+            pygame.WINDOWSIZECHANGED: 'on_window_size_changed',
+            pygame.WINDOWSHOWN: 'on_window_shown',
+            pygame.WINDOWHIDDEN: 'on_window_hidden',
+            pygame.WINDOWHITTEST: 'on_window_hit_test',
+            pygame.WINDOWTAKEFOCUS: 'on_window_take_focus'
         }
         self.hook_mouse = True
         self.is_focusable = True
         self.is_mouse_left_down = False
+        self.is_mouse_enter = True
+        self.scale_x, self.scale_y = 1.0, 1.0
         self.scroll_x, self.scroll_y = 0, 0
         if not cursors:
             compile_cursors()
@@ -38,16 +63,23 @@ class NMainFrame:
         self.export_child = self.child.export_child
         self.import_child = self.child.import_child
         self.sort_child = self.child.sort
+        self.last_cursor_pos = (0, 0)
 
     def set(self, name: str, value: any) -> any:
         setattr(self, name, value)
+        if name == 'scale_x':
+            for child in self.child.child:
+                if child.usable and child.auto_scale:
+                    child.set('scale_x', self.scale_x)
+        elif name == 'scale_y':
+            for child in self.child.child:
+                if child.usable and child.auto_scale:
+                    child.set('scale_y', self.scale_y)
         return self
 
     def process_events(self, events: list) -> list:
         for event in events:
-            func = self.processes.get(event.type)
-            if not func:
-                continue
+            func = self.processes.get(event.type) or self.processes[0]
             getattr(self, '_' + func)(event, hasattr(self, func))
         return events
 
@@ -145,6 +177,7 @@ class NMainFrame:
             self.on_global_mouse_up(event.pos, event.button)  # type: ignore
 
     def _on_global_mouse_move(self, event: pygame.event.Event, bind: bool) -> None:
+        self.last_cursor_pos = event.pos
         if not self.is_mouse_left_down:
             hover = self
             for child in self.child.child[::-1]:
@@ -174,6 +207,22 @@ class NMainFrame:
                 (event.x, event.y), hasattr(event, 'touch') and event.touch, event.flipped
             )
 
+    def _on_global_mouse_enter(self, event: pygame.event.Event, bind: bool) -> None:
+        self.is_mouse_enter = True
+        event.pos = self.last_cursor_pos
+        if bind:
+            self.on_global_mouse_enter(event)  # type: ignore
+
+    def _on_global_mouse_leave(self, event: pygame.event.Event, bind: bool) -> None:
+        self.is_mouse_enter = False
+        event.pos = self.last_cursor_pos
+        if not self.is_mouse_left_down and not self.last_hover == self:
+            self.last_hover._on_mouse_leave(event, hasattr(self.last_hover, 'on_mouse_leave'))
+            self.last_hover = self
+            self._on_mouse_leave(event, hasattr(self, 'on_mouse_enter'))
+        if bind:
+            self.on_global_mouse_leave(event)  # type: ignore
+
     def _on_mouse_wheel(self, event: pygame.event.Event, bind: bool) -> None:
         if bind:
             self.on_mouse_wheel(  # type: ignore
@@ -219,3 +268,87 @@ class NMainFrame:
     def _on_key_up(self, event: pygame.event.Event, bind: bool) -> None:
         if bind:
             self.on_key_up(event)  # type: ignore
+
+    def _on_window_close(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_close(event.window)  # type: ignore
+
+    def _on_active(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_active(event.gain, event.state)  # type: ignore
+
+    def _on_audio_device_added(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_audio_device_added(event.which, event.iscapture)  # type: ignore
+
+    def _on_audio_device_removed(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_audio_device_removed(event.which, event.iscapture)  # type: ignore
+
+    def _on_window_shown(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_shown(event.window)  # type: ignore
+
+    def _on_window_focus_gained(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_focus_gained(event.window)  # type: ignore
+
+    def _on_window_focus_lost(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_focus_lost(event.window)  # type: ignore
+
+    def _on_text_editing(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_text_editing(event.text, event.start, event.length)  # type: ignore
+
+    def _on_video_expose(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_video_expose()  # type: ignore
+
+    def _on_window_exposed(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self._on_window_exposed(event.window)  # type: ignore
+
+    def _on_window_moved(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_moved(event.x, event.y)  # type: ignore
+
+    def _on_text_input(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_text_input(event.text)  # type: ignore
+
+    def _on_video_resize(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_video_resize(event.w, event.h)  # type: ignore
+
+    def _on_window_size_changed(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_size_changed(event.x, event.y)  # type: ignore
+
+    def _on_window_maximized(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_maximized(event.window)  # type: ignore
+
+    def _on_window_restored(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_restored(event.window)  # type: ignore
+
+    def _on_window_minimized(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_minimized(event.window)  # type: ignore
+
+    def _on_window_hidden(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_hidden(event.window)  # type: ignore
+
+    def _on_window_take_focus(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_take_focus(event.window)  # type: ignore
+
+    def _on_window_hit_test(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_window_hit_test(event.window)  # type: ignore
+
+    def _on_unknown_event(self, event: pygame.event.Event, bind: bool) -> None:
+        if bind:
+            self.on_unknown_event(event)  # type: ignore
